package com.qmth.themis.business.cache;

public class RedisKeyHelper {
	private static String underLine = "_";

	/**
	 * 场次
	 */
	private static String examActivityKeyPrefix = "exam_activity::";
	/**
	 * 考生
	 */
	private static String examStudentKeyPrefix = "exam_student::";
	/**
	 * 考试记录
	 */
	private static String examRecordKeyPrefix = "exam_record::";
	/**
	 * 考生试卷结构
	 */
	private static String studentPaperStructKeyPrefix = "student_paper_struct::";
	/**
	 * 考生作答
	 */
	private static String studentAnswerKeyPrefix = "student_answer::";
	/**
	 * 剩余音频播放次数
	 */
	private static String audioLeftPlayCountKeyPrefix = "audio_left_play_count::";
	
	/**
	 * 人脸验证
	 */
	private static String faceVerifyKeyPrefix = "face_verify::";
	
	/**
	 * 活体验证
	 */
	private static String livenessVerifyKeyPrefix = "liveness_verify::";
	

	/**
	 * 场次
	 * 
	 * @param activityId
	 * @return
	 */
	public static String examActivityCacheKey(Long activityId) {
		return examActivityKeyPrefix + activityId;
	}

	/**
	 * 考生
	 * 
	 * @param examStudentId
	 * @return
	 */
	public static String examStudentCacheKey(Long examStudentId) {
		return examStudentKeyPrefix + examStudentId;
	}

	/**
	 * 考试记录
	 * 
	 * @param examRecordId
	 * @return
	 */
	public static String examRecordCacheKey(Long examRecordId) {
		return examRecordKeyPrefix + examRecordId;
	}

	/**
	 * 考生试卷结构
	 * 
	 * @param examRecordId
	 * @return
	 */
	public static String studentPaperStructKey(Long examRecordId) {
		return studentPaperStructKeyPrefix + examRecordId;
	}

	/**
	 * 考生作答
	 * 
	 * @param examRecordId
	 * @return
	 */
	public static String examAnswerKey(Long examRecordId) {
		return studentAnswerKeyPrefix + examRecordId;
	}

	/**
	 * 考生作答 hashKey
	 * 
	 * @param mainNumber
	 * @param subNumber
	 * @param subIndex
	 * @return
	 */
	public static String examAnswerHashKey(Integer mainNumber, Integer subNumber, Integer subIndex) {
		if (subIndex == null) {
			return mainNumber + underLine + subNumber;
		} else {
			return mainNumber + underLine + subNumber + underLine + subIndex;
		}
	}
	
	/**
	 * 音频剩余播放次数
	 * 
	 * @param examRecordId
	 * @return
	 */
	public static String audioLeftPlayCountKey(Long examRecordId) {
		return audioLeftPlayCountKeyPrefix + examRecordId;
	}
	
	/**
	 * 人脸验证
	 * 
	 * @param id
	 * @return
	 */
	public static String faceVerifyCacheKey(Long id) {
		return faceVerifyKeyPrefix + id;
	}
	
	/**
	 * 活体验证
	 * 
	 * @param id
	 * @return
	 */
	public static String livenessVerifyCacheKey(Long id) {
		return livenessVerifyKeyPrefix + id;
	}

}
